==> paraview_5.7.0.orig.tar.xz: paraview-5.7.0/Qt/Components/pqDialog.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqDialog.cxx

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqDialog.h"

//-----------------------------------------------------------------------------
pqDialog::pqDialog(QWidget* _parent /*=0*/, Qt::WindowFlags f /*=0*/)
  : QDialog(_parent, f)
{
  this->UndoLabel = "Dialog";
}

//-----------------------------------------------------------------------------
pqDialog::~pqDialog()
{
}

//-----------------------------------------------------------------------------
void pqDialog::accept()
{
  emit this->beginUndo(this->UndoLabel);
  this->acceptInternal();
  this->Superclass::accept();
  emit this->endUndo();
}

//-----------------------------------------------------------------------------
void pqDialog::done(int r)
{
  emit this->beginUndo(this->UndoLabel);
  this->doneInternal(r);
  this->Superclass::done(r);
  emit this->endUndo();
}

==> paraview_5.9.0.orig.tar.xz: paraview-5.9.0/Qt/Components/pqDialog.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqDialog.cxx

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqDialog.h"

//-----------------------------------------------------------------------------
pqDialog::pqDialog(QWidget* _parent /*=0*/, Qt::WindowFlags f /*=0*/)
  : QDialog(_parent, f)
{
  this->UndoLabel = "Dialog";
}

//-----------------------------------------------------------------------------
pqDialog::~pqDialog()
{
}

//-----------------------------------------------------------------------------
void pqDialog::accept()
{
  Q_EMIT this->beginUndo(this->UndoLabel);
  this->acceptInternal();
  this->Superclass::accept();
  Q_EMIT this->endUndo();
}

//-----------------------------------------------------------------------------
void pqDialog::done(int r)
{
  Q_EMIT this->beginUndo(this->UndoLabel);
  this->doneInternal(r);
  this->Superclass::done(r);
  Q_EMIT this->endUndo();
}
